@@ -28,6 +28,7 @@ __author__ = ('tav@espians.com (tav),'
 __maintainer__ = 'jordan.bouvier@analytemedia.com (Jordan Bouvier)'
 
 import csv
+import logging
 
 try:
     from cStringIO import StringIO
@@ -48,7 +49,7 @@ except ImportError:
         except ImportError:
             from elementtree import ElementTree
 
-from yaml import dump
+from yaml import dump, safe_dump
 
 
 DEFAULT_CONTACT_FIELDS = ('first name', 'last_name', 'email', 'tags')
@@ -150,6 +151,8 @@ class MadMimi(object):
         self.api_key = api_key
 
         self.urlopen = urlopen
+        self.logger = logging.getLogger('madmimi')
+        self.logger.setLevel(logging.WARNING)
 
     def _get(self, method, **params):
         """Issue a GET request to Madmimi.
@@ -171,8 +174,11 @@ class MadMimi(object):
         params['username'] = self.username
         params['api_key'] = self.api_key
         url = url + method + '?' + urlencode(params)
+        self.logger.debug('get url: %s' % url)
 
-        return self.urlopen(url).read()
+        response = self.urlopen(url).read()
+        self.logger.debug('response: %s' % response)
+        return response
 
     def _post(self, method, **params):
         """Issue a POST request to Madmimi.
@@ -195,8 +201,13 @@ class MadMimi(object):
         params['api_key'] = self.api_key
         if params.get('sender'):
             params['from'] = params['sender']
+        
+        self.logger.debug('post url: %s' % url)
+        self.logger.debug('params: %s' % params)
 
-        return self.urlopen(url, urlencode(params)).read()
+        response = self.urlopen(url, urlencode(params)).read()
+        self.logger.debug('response: %s' % response)
+        return response
 
     def lists(self, as_xml=False):
         """Get a list of audience lists.
@@ -350,7 +361,7 @@ class MadMimi(object):
             # The YAML dump will fail if it encounters non-strings
             for item, value in body.iteritems():
                 body[item] = str(value)
-            body = dump(body)
+            body = safe_dump(body) # to avoid !!python/str tags by dump(body)
             
             post = self._post('mailer', promotion_name=promotion,
                     recipients=recipients, subject=subject, sender=sender,
@@ -376,7 +387,7 @@ class MadMimi(object):
         for item, value in body.iteritems():
             body[item] = str(value)
 
-        body = dump(body)
+        body = safe_dump(body) # to avoid !!python/str tags by dump(body)
 
         return self._post('mailer/to_list', promotion_name=promotion,
                 list_name=list_name, body=body, is_secure=True)
